@@ -68,7 +68,7 @@ class Interaction():
         
         :type: :class:`discord.TextChannel` | :class:`discord.DMChannel`
         """
-        return self._state.get_channel(self.channel_id)
+        return self._state.get_channel(self.channel_id) or self._state.get_channel(self.author.id)
 
     async def defer(self, hidden=False):
         """
@@ -268,7 +268,7 @@ class Interaction():
 
         if hidden is True:
             msg = EphemeralMessage(state=self._state, channel=self._state.get_channel(r["channel_id"]), data=r, application_id=self.application_id, token=self.token)
-            if listener is not None:
+            if listener is not MISSING:
                 listener._start(msg)
         msg = await getMessage(self._state, r, response=False)
         
@@ -355,7 +355,7 @@ class SlashedContext(Interaction, ContextCommand):
         
 
 
-async def getMessage(state: ConnectionState, data, response = True):
+async def getMessage(state: ConnectionState, data, response=True):
     """
     Async function to get the response message
 
@@ -376,15 +376,17 @@ async def getMessage(state: ConnectionState, data, response = True):
     :class:`~Message` | :class:`~EphemeralMessage`
         The sent message
     """
-    channel = state.get_channel(int(data["channel_id"])) or state._get_private_channel_by_user(data["message"]["author"]["id"])
-    if response:
-        if data.get("message") is not None and data.get("message", data)["flags"] == 64:
-            return EphemeralResponseMessage(state=state, channel=channel, data=data.get("message", data))
-        return Message(state=state, channel=channel, data=data.get("message", data))
+    msg_base = data.get("message", data)
 
-    if data.get("message") is not None and data["message"]["flags"] == 64:
-        return EphemeralMessage(state=state, channel=channel, data=data.get("message", data))
-    return Message(state=state, channel=channel, data=data.get("message", data))
+    channel = state.get_channel(int(data["channel_id"])) or state.get_channel(int(msg_base["author"]["id"]))
+    if response:
+        if msg_base["flags"] == 64:
+            return EphemeralResponseMessage(state=state, channel=channel, data=data.get("message", data))
+        return Message(state=state, channel=channel, data=msg_base)
+
+    if msg_base["flags"] == 64:
+        return EphemeralMessage(state=state, channel=channel, data=msg_base)
+    return Message(state=state, channel=channel, data=msg_base)
 
 class Message(discord.Message):
     """A fixed :class:`discord.Message` optimized for components"""
@@ -685,6 +687,11 @@ class WebhookMessage(Message, discord.WebhookMessage):
 class EphemeralMessage(Message):
     """Represents a hidden (ephemeral) message"""
     def __init__(self, state, channel, data, application_id=None, token=None):
+        #region fix reference keyerror
+        if data.get("message_reference"):
+            if data["message_reference"].get("channel_id") is None:
+                data["message_reference"]["channel_id"] = str(channel.id)
+        #endregion
         Message.__init__(self, state=state, channel=channel, data=data)
         self._application_id = application_id
         self._interaction_token = token
